@@ -27,6 +27,24 @@ sizeDict = {
     "string" : 16,
 }
 
+cNameDict = {
+    "uint8" : "uint8_t",
+     "int8" : "int8_t",
+     "char" : "char",
+     "string" : "char",
+     "uint16" : "uint16_t",
+     "int16" : "int16_t",
+     "uint32" : "uint32_t",
+     "int32" : "int32_t",
+     "int64" : "int64_t",
+     "uint64" : "uint64_t",
+     "int" : "int",
+     "float" : "float",
+     "double" : "double",
+     "enum" : "uint8_t",
+     "flag" : "uint8_t"
+ }
+
 args = None
 parser = None
 
@@ -269,7 +287,7 @@ class DeviceReg:
     def __init__(self,name):
         self.name = name
         self.addr = 0
-        self.type ="uint8_t"
+        self.type ="uint8"
         self.perm = "RW"
         self.desc = ""
         self.default = 0
@@ -533,7 +551,7 @@ class Device:
                 if 'addr' in regItem:
                     newReg.addr = regItem['addr'] #int(regItem['addr'],0) 
                 if 'type' in regItem:
-                    newReg.type = regItem['type']
+                    newReg.type = regItem['type'].replace("_t","")
                     newReg.size = sizeDict[newReg.type.replace("_t","")]
                 if 'size' in regItem:
                     newReg.size = regItem['size']
